==> grantlee5_5.1.0.orig.tar.gz: grantlee-5.1.0/templates/defaulttags/ifchanged.h <==
/*
  This file is part of the Grantlee template system.

  Copyright (c) 2009,2010 Stephen Kelly <steveire@gmail.com>

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either version
  2.1 of the Licence, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library.  If not, see <http://www.gnu.org/licenses/>.

*/

#ifndef IFCHANGEDNODE_H
#define IFCHANGEDNODE_H

#include "node.h"

using namespace Grantlee;

class IfChangedNodeFactory : public AbstractNodeFactory
{
  Q_OBJECT
public:
  IfChangedNodeFactory();

  Node *getNode(const QString &tagContent, Parser *p) const override;
};

class IfChangedNode : public Node
{
  Q_OBJECT
public:
  explicit IfChangedNode(const QList<FilterExpression> &feList,
                         QObject *parent = 0);

  void setTrueList(const NodeList &trueList);
  void setFalseList(const NodeList &falseList);

  void render(OutputStream *stream, Context *c) const override;

private:
  NodeList m_trueList;
  NodeList m_falseList;
  QList<FilterExpression> m_filterExpressions;
  mutable QVariant m_lastSeen;
  QString m_id;
};

#endif

==> grantlee5_5.3.1.orig.tar.gz: grantlee-5.3.1/templates/defaulttags/ifchanged.h <==
/*
  This file is part of the Grantlee template system.

  Copyright (c) 2009,2010 Stephen Kelly <steveire@gmail.com>

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either version
  2.1 of the Licence, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library.  If not, see <http://www.gnu.org/licenses/>.

*/

#ifndef IFCHANGEDNODE_H
#define IFCHANGEDNODE_H

#include "node.h"

using namespace Grantlee;

class IfChangedNodeFactory : public AbstractNodeFactory
{
  Q_OBJECT
public:
  IfChangedNodeFactory();

  Node *getNode(const QString &tagContent, Parser *p) const override;
};

class IfChangedNode : public Node
{
  Q_OBJECT
public:
  explicit IfChangedNode(const QList<FilterExpression> &feList,
                         QObject *parent = {});

  void setTrueList(const NodeList &trueList);
  void setFalseList(const NodeList &falseList);

  void render(OutputStream *stream, Context *c) const override;

private:
  NodeList m_trueList;
  NodeList m_falseList;
  QList<FilterExpression> m_filterExpressions;
  mutable QVariant m_lastSeen;
  QString m_id;
};

#endif
